The python package `bfcm` includes the functions related to the journal paper "Modeling Implicit Bias with Fuzzy Cognitive Maps" by Gonzalo Nápoles, Isel Grau, Leonardo Concepción, Lisa Koutsoviti Koumeri and João Paulo Papa (see here https://doi.org/10.1016/j.neucom.2022.01.070). No demostration is available yet - should be added soon.

The file `Code_Neurocomputing_submission` includes the experimental setup of the abovementioned journal paper.

The file `Code_IntelliSys2023_submission` includes the Jupyter notebook and datasets for the conference paper "Measuring Implicit Bias Using SHAP Feature Importance and Fuzzy Cognitive Maps" by Gonzalo Nápoles, Isel Grau, Fabian Hoitsma, Lisa Koutsoviti Koumeri and Koen Vanhoof. The paper is to be presented at the Intelligent Systems Conference (IntelliSys) 2023 in September 2023 and the proceedings will be published in the Springer series "Lecture Notes in Networks and Systems".